Skip to contents

These are meant to be used to indicate what kind of analysis is meant to be carried out.

Usage

TraversalType

Value

A list of numbers representing each particular analysis type

Examples

TraversalType$Angular
#> [1] 1
TraversalType$Topological
#> [1] 2
TraversalType$Metric
#> [1] 3