alcyon-coercion: Coercion between sf and alcyon map classes

alcyon-coercionR Documentation

Coercion between sf and alcyon map classes

Description

Direct conversions between sf objects and the map classes provided by this package. For ShapeMap -> Axial -> Segment see axialToSegmentShapeGraph.

This is a direct conversion, for ShapeMap -> Axial -> Segment see axialToSegmentShapeGraph

This is a direct conversion, for ShapeMap -> Axial -> Segment see axialToSegmentShapeGraph

Usage

## S4 method for signature 'sf,ShapeMap'
coerce(from, to = "ShapeMap", strict = TRUE)

## S4 method for signature 'ShapeMap,sf'
coerce(from, to = "sf", strict = TRUE)

## S4 method for signature 'ShapeMap,AxialShapeGraph'
coerce(from, to = "AxialShapeGraph", strict = TRUE)

## S4 method for signature 'sf,AxialShapeGraph'
coerce(from, to = "AxialShapeGraph", strict = TRUE)

## S4 method for signature 'ShapeMap,SegmentShapeGraph'
coerce(from, to = "SegmentShapeGraph", strict = TRUE)

## S4 method for signature 'sf,SegmentShapeGraph'
coerce(from, to = "SegmentShapeGraph", strict = TRUE)

Arguments

from

the object to coerce.

to

the target class. Supplied by as and not used by the method bodies.

strict

logical, part of the coerce generic signature. Not used by the method bodies.

See Also

Other ShapeMap: ShapeMap-class

Other AxialShapeGraph: AxialShapeGraph-class

Other SegmentShapeGraph: SegmentShapeGraph-class


alcyon documentation built on Aug. 30, 2026, 1:07 a.m.